==> Tagz-1.0.0.zip: Tagz/lang/es.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Palabras clave',
 'L_TITLE'=>'Editar palabras clave del sitio',
 'L_DESCRIPTION'=>'Administrar etiquetas de sitio. Eliminar o renombrar el conjunto de palabras clave.',
#admin
 'L_CANCEL'=>'Cancelar todo',
 'L_DEVIENT'=>'se convierte en',
 'L_POUR'=>'para',
 'L_SEARCH'=>'Buscar en artículos con esta palabra clave',
 'L_RESTORE'=>'restaurar',
 'L_DEL'=>'borrar',
 'L_RESTORE_ALL'=>'Restaurar todos los campos vacíos',
 'L_DEL_ALL'=>'Borrar todos los campos',
 'L_ART_NUM'=>'Para el artículo (s) con número (s)',
 'L_HELP_TAG_FIELD'=>'Si el campo está vacío, se elimina la palabra clave después de guardar.'.PHP_EOL.'La combinaison de touche Ctrl + z permet d’annuler',
 'L_TAGS_REFRESH'=>'refrescar',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Archivo Tags.xml actualizado por las palabras clave de los artículos.',
 'L_TAG_PLACEHOLDER'=>'Borrado si se deja vacío',
 'L_DEDUPLICATED'=>'deduplicado',
 'L_IN_REALITY'=>'En realidad',
 'L_IS_UNIK'=>'Único (es solo)',
 'L_DOUBLES'=>'doble',
 'L_TRIPLES'=>'triples',
 'L_QUADRUPLES'=>'cuádruple',
 'L_QUINTUPLES'=>'quíntuplo',
 'L_SEXTUPLES'=>'séxtuplo',
 'L_SEPTUPLES'=>'siete veces',
#config
 'L_ACCES'=>'Tipo (s) de cuenta (s) * autorizados para acceder al complemento',
 'L_HELP_ACCES'=>'Qué perfiles * están autorizados a utilizar el complemento. Lista separada por comas (Predeterminado PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Usuario (s) prohibido acceder al complemento (menú oculto)',
 'L_HELP_DENY'=>'Cuáles son los identificadores de los usuarios a los que está prohibido utilizar el complemento. Lista separada por comas (por ejemplo, 001,002,007).'
);
?>

==> Tagz-1.0.4.zip: Tagz/lang/es.php <==
<?php
$LANG = array(
 'P_MENU'=>'0',
 'L_MENU_TAGS'=>'Palabras clave',
 'L_TITLE'=>'Editar palabras clave del sitio',
 'L_DESCRIPTION'=>'Administrar etiquetas de sitio. Eliminar o renombrar el conjunto de palabras clave.',
 'L_FILTER_TAGS'=>'Filtrar palabras clave',
 'L_FILTER_TAGS_PH'=>'Filtro de palabras',
 'L_CANCEL'=>'Cancelar todo',
 'L_DEVIENT'=>'se convierte en',
 'L_POUR'=>'para',
 'L_SEARCH'=>'Buscar en artículos con esta palabra clave',
 'L_RESTORE'=>'restaurar',
 'L_DEL'=>'borrar',
 'L_RESTORE_ALL'=>'Restaurar todos los campos vacíos',
 'L_DEL_ALL'=>'Borrar todos los campos',
 'L_ART_NUM'=>'Para el artículo (s) con número (s)',
 'L_HELP_TAG_FIELD'=>'Si el campo está vacío, se elimina la palabra clave después de guardar.',
 'L_HELP_TAG_CTRLZ'=>'La combinación de teclas Ctrl-z le permite cancelar',
 'L_TAGS_REFRESH'=>'refrescar',
 'L_TAGS_REFRESHED_BY_ARTICLES'=>'Archivo Tags.xml actualizado por las palabras clave de los artículos.',
 'L_TAG_PLACEHOLDER'=>'Borrado si se deja vacío',
 'L_DEDUPLICATED'=>'deduplicado',
 'L_IN_REALITY'=>'En realidad',
 'L_IS_UNIK'=>'Único (es solo)',
 'L_DOUBLES'=>'doble',
 'L_TRIPLES'=>'triples',
 'L_QUADRUPLES'=>'cuádruple',
 'L_QUINTUPLES'=>'quíntuplo',
 'L_SEXTUPLES'=>'séxtuplo',
 'L_SEPTUPLES'=>'siete veces',
 'L_OCTUPLES'=>'Octuples',
 'L_NONUPLES'=>'Nonuples',
 'L_DECUPLES'=>'Décuplo',
#config
 'L_ACCES'=>'Tipo (s) de cuenta (s) * autorizados para acceder al complemento',
 'L_HELP_ACCES'=>'Qué perfiles * están autorizados a utilizar el complemento. Lista separada por comas (Predeterminado PROFIL_ADMIN, PROFIL_MANAGER).',
 'L_DENY'=>'Usuario (s) prohibido acceder al complemento (menú oculto)',
 'L_HELP_DENY'=>'Cuáles son los identificadores de los usuarios a los que está prohibido utilizar el complemento. Lista separada por comas (por ejemplo, 001,002,007).',
);
?>
